@@ -1,7 +1,7 @@
 package AnyEvent::Net::Amazon::S3::Client::Object;
 
 # ABSTRACT: An easy-to-use Amazon S3 client object
-our $VERSION = 'v0.03.0.60'; # VERSION
+our $VERSION = 'v0.04.0.80'; # VERSION
 
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ use warnings;
 use Module::AnyEvent::Helper::Filter -as => __PACKAGE__, -target => 'Net::Amazon::S3::Client::Object',
         -transformer => 'Net::Amazon::S3::Client::Object',
         -translate_func => [qw(exists _get get get_decoded get_filename _put put put_filename delete
-                               initiate_multipart_upload complete_multipart_upload put_part)],
+                               initiate_multipart_upload complete_multipart_upload abort_multipart_upload put_part)],
         -replace_func => [qw(_send_request_raw _send_request _send_request_xpc)]
 ;
 
@@ -29,7 +29,7 @@ AnyEvent::Net::Amazon::S3::Client::Object - An easy-to-use Amazon S3 client obje
 
 =head1 VERSION
 
-version v0.03.0.60
+version v0.04.0.80
 
 =head1 SYNOPSIS
 
@@ -70,6 +70,13 @@ version v0.03.0.60
   # return the URI of a publically-accessible object
   my $uri = $object->uri;
 
+  # to store a new object with server-side encryption enabled
+  my $object = $bucket->object(
+    key        => 'my secret',
+    encryption => 'AES256',
+  );
+  $object->put('this data will be stored using encryption.');
+
   # upload a file
   my $object = $bucket->object(
     key          => 'images/my_hat.jpg',
@@ -134,6 +141,8 @@ You can get actual return value by calling C<shift-E<gt>recv()>.
 
 =item initiate_multipart_upload_async
 
+=item abort_multipart_upload_async
+
 =item put_part_async
 
 =back
@@ -141,6 +150,7 @@ You can get actual return value by calling C<shift-E<gt>recv()>.
 =for Pod::Coverage list_parts
 query_string_authentication_uri
 uri
+get_callback
 
 =head1 AUTHOR
 
